close all
clear all
load Den_DyFk40_smooth.dat
load Vel_DyFk40_smooth.dat
load Tpr_DyFk40_smooth.dat
load Tpp_DyFk40_smooth.dat

load MLAT_DyFk40.dat
load ALT_DyFk40.dat
load sg_GSK40.dat
load GRIDFLIP40.dat

jbn=50;         % the grid point in FLIP below 800km
jbs=350;         % the grid point in FLIP below 800km  
jbfn=1;          % the grid point in GSK above 800km
jbfs=101;        % the grid point in GSK above 800km
jmax=399;        % the number of rows in 'FLIP25.dat'
num=jbn+jmax-jbs+1+jbfs-jbfn+1;    % num of grid points
Re=6371.2;    % km

nstep=49;
UT=[0:1:48];
UT=UT';

s1=GRIDFLIP40(:,3);       %  arc length in km in FLIP
s1=s1./Re;
s0=s1(200);
s1=s1-s0;                  % arc length at equator is zero

s2=sg_GSK40;    % arc length in GSK and origin at equator

x1=jbn;
x2=x1+1;
x3=jbn+jbfs-jbfn+1;
x4=x3+1;
sg(1:x1)=s1(1:jbn);
sg(x2:x3)=s2(:);
sg(x4:num)=s1(jbs:jmax);      %  arc length for DyFk

MLAT=MLAT_DyFk40;
ALT=ALT_DyFk40;     % in km
RR=ALT./Re+1.0;     % radial distance in Re

Den=Den_DyFk40_smooth;
Vel=Vel_DyFk40_smooth;
Tpr=Tpr_DyFk40_smooth;
Tpp=Tpp_DyFk40_smooth;

% density in cm^-3
NO=reshape(Den(:,1),num,nstep);
NO=NO';

NH=reshape(Den(:,2),num,nstep);
NH=NH';

NHe=reshape(Den(:,3),num,nstep);
NHe=NHe';

Ne=reshape(Den(:,4),num,nstep);
Ne=Ne';

% Parallel temperature 
TprO=reshape(Tpr(:,1),num,nstep);
TprO=TprO';

TprH=reshape(Tpr(:,2),num,nstep);
TprH=TprH';

TprHe=reshape(Tpr(:,3),num,nstep);
TprHe=TprHe';

Tpre=reshape(Tpr(:,4),num,nstep);
Tpre=Tpre';

% Perpendicular temperature 
TppO=reshape(Tpp(:,1),num,nstep);
TppO=TppO';

TppH=reshape(Tpp(:,2),num,nstep);
TppH=TppH';

TppHe=reshape(Tpp(:,3),num,nstep);
TppHe=TppHe';

Tppe=reshape(Tpp(:,4),num,nstep);
Tppe=Tppe';

% velocity in m/s
VO=reshape(Vel(:,1),num,nstep);
VO=VO';

VH=reshape(Vel(:,2),num,nstep);
VH=VH';

VHe=reshape(Vel(:,3),num,nstep);
VHe=VHe';

Ve=reshape(Vel(:,4),num,nstep);
Ve=Ve';

%  pressure
TO=(TprO+2.0*TppO)/3.0;
PO=TO.*NO;

TH=(TprH+2.0*TppH)/3.0;
PH=TH.*NH;

THe=(TprHe+2.0*TppHe)/3.0;
PHe=THe.*NHe;

Te=(Tpre+2.0*Tppe)/3.0;
Pe=Te.*Ne;

P2=log10(PO);    %  normalized pressure
%P2=PH;
Pmax=max(P2);
Pmax2=max(Pmax);
Pnor=P2./Pmax2; 

% density above 300km
subplot(2,2,1)
plot(MLAT(7:195),NO(43,7:195),'-r','LineWidth',3)
hold on
plot(MLAT(7:195),NH(43,7:195),'--b','LineWidth',3)
hold on
plot(MLAT(7:195),NHe(43,7:195),'--g','LineWidth',3)
xlabel('MLAT (degree)','fontsize',20)
ylabel('N (cm^{-3})','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'Xlim',[-60,60],'XTick',[-60:20:60])
set(gca,'Yscale','log','Ylim',[1e-2,1e6],'YTick',[1e-2,1e0,1e2,1e4,1e6])
text(-55,0.1,'(a)','FontSize',18)
% velocity
subplot(2,2,2)
plot(MLAT(7:195),VO(43,7:195),'-r','LineWidth',3)
hold on
plot(MLAT(7:195),VH(43,7:195),'--b','LineWidth',3)
hold on
plot(MLAT(7:195),VHe(43,7:195),'--g','LineWidth',3)
xlabel('MLAT (degree)','fontsize',20)
ylabel('V (m/s)','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'Xlim',[-60,60],'XTick',[-60:20:60])
text(50,-150,'(b)','FontSize',18)
%parallel temperature
subplot(2,2,3)
plot(MLAT(7:195),TprO(43,7:195),'-r','LineWidth',3)
hold on
plot(MLAT(7:195),TprH(43,7:195),'--b','LineWidth',3)
hold on
plot(MLAT(7:195),TprHe(43,7:195),'--g','LineWidth',3)
xlabel('MLAT (degree)','fontsize',20)
ylabel('Tpr (K)','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'Xlim',[-60,60],'XTick',[-60:20:60])
text(-55,1000,'(c)','FontSize',18)
%perpendicular temperature
subplot(2,2,4)
plot(MLAT(7:195),TppO(43,7:195),'-r','LineWidth',3)
hold on
plot(MLAT(7:195),TppH(43,7:195),'--b','LineWidth',3)
hold on
plot(MLAT(7:195),TppHe(43,7:195),'--g','LineWidth',3)
xlabel('MLAT (degree)','fontsize',20)
ylabel('Tpp (K)','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'Xlim',[-60,60],'XTick',[-60:20:60])
text(50,1000,'(d)','FontSize',18)
legend('O^+','H^+','He^+')
