close all
clear all
load Den_DyFk30.dat
load Vel_DyFk30.dat
load Tpr_DyFk30.dat
load Tpp_DyFk30.dat

load MLAT_DyFk30.dat
load ALT_DyFk30.dat
load sg_GSK30.dat
load GRIDFLIP30.dat

jbn=65;         % the grid point in FLIP below 800km
jbs=335;         % the grid point in FLIP below 800km  
jbfn=1;          % the grid point in GSK above 800km
jbfs=120;        % the grid point in GSK above 800km
jmax=399;        % the number of rows in 'FLIP25.dat'
num=jbn+jmax-jbs+1+jbfs-jbfn+1;    % num of grid points
Re=6371.2;

nstep=73;
UT=[0:1:72];
UT=UT';

s1=GRIDFLIP30(:,3);       %  arc length in km in FLIP
s1=s1./Re;
s0=s1(200);
s1=s1-s0;                  % arc length at equator is zero

s2=sg_GSK30;    % arc length in GSK and origin at equator

x1=jbn;
x2=x1+1;
x3=jbn+jbfs-jbfn+1;
x4=x3+1;
sg(1:x1)=s1(1:jbn);
sg(x2:x3)=s2(:);
sg(x4:num)=s1(jbs:jmax);      %  arc length for DyFk

MLAT=MLAT_DyFk30;
ALT=ALT_DyFk30;

Den=Den_DyFk30;
Vel=Vel_DyFk30;
Tpr=Tpr_DyFk30;
Tpp=Tpp_DyFk30;

% density in cm^-3
NO=reshape(Den(:,1),num,nstep);
NO=NO';

NH=reshape(Den(:,2),num,nstep);
NH=NH';

NHe=reshape(Den(:,3),num,nstep);
NHe=NHe';

Ne=reshape(Den(:,4),num,nstep);
Ne=Ne';

% Parallel temperature 
TprO=reshape(Tpr(:,1),num,nstep);
TprO=TprO';

TprH=reshape(Tpr(:,2),num,nstep);
TprH=TprH';

TprHe=reshape(Tpr(:,3),num,nstep);
TprHe=TprHe';

Tpre=reshape(Tpr(:,4),num,nstep);
Tpre=Tpre';

% Perpendicular temperature 
TppO=reshape(Tpp(:,1),num,nstep);
TppO=TppO';

TppH=reshape(Tpp(:,2),num,nstep);
TppH=TppH';

TppHe=reshape(Tpp(:,3),num,nstep);
TppHe=TppHe';

Tppe=reshape(Tpp(:,4),num,nstep);
Tppe=Tppe';

% velocity in m/s
VO=reshape(Vel(:,1),num,nstep);
VO=VO';

VH=reshape(Vel(:,2),num,nstep);
VH=VH';

VHe=reshape(Vel(:,3),num,nstep);
VHe=VHe';

Ve=reshape(Vel(:,4),num,nstep);
Ve=Ve';

%  pressure
PO=(TprO+2.0*TppO)/3.0;
PO=PO.*NO;

PH=(TprH+2.0*TppH)/3.0;
PH=PH.*NH;

PHe=(TprHe+2.0*TppHe)/3.0;
PHe=PHe.*NHe;

Pe=(Tpre+2.0*Tppe)/3.0;
Pe=Pe.*Ne;

P2=log10(PO);    %  normalized pressure
Pmax=max(P2);
Pmax2=max(Pmax);
Pnor=P2./Pmax2; 

y=log10(NO);

%surface(MLAT,UT,Pnor)
surface(sg,UT,VH)
%contour(MLAT,UT,y,15,'LineWidth',3)
%caxis([0.2,1])
xlabel('MLAT (degree)','fontsize',20)
ylabel('UT (hour)','fontsize',20)
set(gca,'fontsize',18,'LineWidth',2)
set(gca,'TickDir','out')
%set(gca,'XMinorTick','on','YMinorTick','on','TickLength',[0.015,0.025])
set(gca,'XMinorTick','on','YMinorTick','on')
set(gca,'Ylim',[0,72])
colorbar('LineWidth',3,'Fontsize',16)
box on
title('NH^+ (cm^{-3})','Fontsize',18)