clear all

load GRID_GSK_Time2hrs_wave3.dat
load EFD_GSK_Time2hrs.dat
% electric field in the case with wave heating for 2 hours
load EFD_GSK_Time2hrs_wave3.dat   % P=1e-10
load EFD_GSK_Time2hrs_wave5.dat   % P=1e-9
load EFD_GSK_Time2hrs_wave6.dat   % P=1e-11

nc=281;
nstep=9;
num=280;

t=[0:0.25:2.0];
t=t';
UT=[12.0:0.25:14.0];
UT=UT';
GRID=GRID_GSK_Time2hrs_wave3;

% radial distance in Re
rr=reshape(GRID(:,1),nc,nstep);
rr=rr';

% altitude in km
ALT=reshape(GRID(:,2),nc,nstep);
ALT=ALT';
% Geomagnetic latitude in degree
MLAT=reshape(GRID(:,3),nc,nstep);
MLAT=MLAT';
% magnitude of magnetic field in Tesla
bfd=reshape(GRID(:,4),nc,nstep);
bfd=bfd';
% arc length in Re
sg=reshape(GRID(:,5),nc,nstep);
sg=sg';

EFD=EFD_GSK_Time2hrs;
EFD3=EFD_GSK_Time2hrs_wave3;
EFD5=EFD_GSK_Time2hrs_wave5;
EFD6=EFD_GSK_Time2hrs_wave6;

% electric field
efield=reshape(EFD(:,1),nc,nstep);
efield=efield';
efield=efield.*1e+7;
% electric potential
poten=reshape(EFD(:,2),nc,nstep);
poten=poten';


% electric field with wave
efield3=reshape(EFD3(:,1),nc,nstep);
efield3=efield3';
efield3=efield3.*1e+7;
% electric potential with wave
poten3=reshape(EFD3(:,2),nc,nstep);
poten3=poten3';


% electric field with wave
efield5=reshape(EFD5(:,1),nc,nstep);
efield5=efield5';
efield5=efield5.*1e+7;
% electric potential with wave
poten5=reshape(EFD5(:,2),nc,nstep);
poten5=poten5';


% electric field with wave
efield6=reshape(EFD6(:,1),nc,nstep);
efield6=efield6';
efield6=efield6.*1e+7;
% electric potential with wave
poten6=reshape(EFD6(:,2),nc,nstep);
poten6=poten6';

subplot(1,2,1)
plot(MLAT(9,:),efield(9,:),'-k','LineWidth',2)
hold on
plot(MLAT(9,:),efield6(9,:),'--g','LineWidth',2)
hold on
plot(MLAT(9,:),efield3(9,:),'-.b','LineWidth',2)
hold on
plot(MLAT(9,:),efield5(9,:),'-r','LineWidth',2)
hold on
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('Electric Field (10^{-7} V/m)','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on','Xlim',[-50,50]);
legend('P_0=0', 'P_0=10^{-11}', ...,
    'P_0=10^{-10}','P_0=10^{-9}')

subplot(1,2,2)
plot(MLAT(9,:),poten(9,:),'-k','LineWidth',2)
hold on
plot(MLAT(9,:),poten6(9,:),'--g','LineWidth',2)
hold on
plot(MLAT(9,:),poten3(9,:),'-.b','LineWidth',2)
hold on
plot(MLAT(9,:),poten5(9,:),'-r','LineWidth',2)
hold on
set(gca,'FontSize',18,'LineWidth',2,'TickLength',[0.015,0.025]);
ylabel('Electric Potential (V)','fontsize',20)
xlabel('MLAT (degree)','fontsize',20)
set(gca,'XMinorTick','on');
legend('P_0=0', 'P_0=10^{-11}', ...,
    'P_0=10^{-10}','P_0=10^{-9}')

