clear all

load GRID_GSK_Time.dat
load EFD_GSK_Time.dat

load Neq_GSK_Time.dat
load L_time_forward.dat

D=L_time_forward;
% equatorial density in cm^-3
den=Neq_GSK_Time;

z=size(D(:,1));
% start from UT=1.3 h  
L=D(1:z,2);   % L shell with time interval 30 min

L=L';

nstep=15;
UT0=7.0;   % start at UT=1.3 h

t=[0.0:0.5:7.0];
t=t';
UT=[7.0:0.5:14.0];
UT=UT';

nc=101;
nstep=15;

GRID=GRID_GSK_Time;
Re=6371.2e3;    %m
num=nc-1;
x=num/2+1;

% radial distance in Re
rr=reshape(GRID(:,1),nc,nstep);
rr=rr';

% altitude in km
ALT=reshape(GRID(:,2),nc,nstep);
ALT=ALT';
% Geomagnetic latitude in degree
MLAT=reshape(GRID(:,3),nc,nstep);
MLAT=MLAT';
% magnitude of magnetic field in Tesla
bfd=reshape(GRID(:,4),nc,nstep);
bfd=bfd';
% arc length in Re
sg=reshape(GRID(:,5),nc,nstep);
sg=sg';
%gravitational acceleration in Re/s^2
gm=reshape(GRID(:,6),nc,nstep);
gm=gm';
gm=gm.*Re;   %  in units of m/s^2;

EFD=EFD_GSK_Time;

% electric field
efield=reshape(EFD(:,1),nc,nstep);
efield=efield';
% efield=efield.*1e+7;

% electric potential
% electric potential in V
poten(1:nstep,1:nc)=0.0;
for j=1:nstep;
    for i=2:nc;
        poten(j,i)=poten(j,i-1)-0.5*(efield(j,i)+efield(j,i-1))*(sg(j,i)-sg(j,i-1))*Re;
    end
end

for j=1:nstep;
    temp=poten(j,x);
    for i=1:nc;
        poten(j,i)=poten(j,i)-temp;
    end
end

% gravitational potential in m^2/s^2
gpoten(1:nstep,1:nc)=0.0;
for j=1:nstep;
for i=2:nc;
    gpoten(j,i)=gpoten(j,i-1)-0.5*(gm(j,i)+gm(j,i-1))*(sg(j,i)-sg(j,i-1))*Re;
end
end

mH=1.67e-27;   % kg
mO=16.0*mH;
mHe=4.0*mH;
me=9.11e-31;
q=1.6e-19;   % electric charge

GO=gpoten.*mO/q;   %  gravitational potential energy in eV, assuming GO=0 at 800km
GH=gpoten.*mH/q;
GHe=gpoten.*mHe/q;

% electric potential energy in eV at 800km, assuming EP=0 at equator
for j=1:nstep;
    EP(j)=0.5*(poten(j,1)+poten(j,nc));
end
% potential energy difference between equator and 800 km in eV
for j=1:nstep;
    dWO(j)=GO(j,x)-EP(j);
    dWH(j)=GH(j,x)-EP(j);
    dWHe(j)=GHe(j,x)-EP(j);
end
% potential energy difference between equator and 800 km in northern
% hemisphere
for j=1:nstep;
    dWOn(j)=GO(j,x)-poten(j,1);
    dWHn(j)=GH(j,x)-poten(j,1);
    dWHen(j)=GHe(j,x)-poten(j,1);
end

% potential energy difference between equator and 800 km in southern
% hemisphere
for j=1:nstep;
    dWOs(j)=GO(j,x)-poten(j,nc);
    dWHs(j)=GH(j,x)-poten(j,nc);
    dWHes(j)=GHe(j,x)-poten(j,nc);
end
plot(L,dWHe)
