! Densities are calculated at the grid points (100 points) which are
! distributed uniformly along the magnetic field line
! Created by Yan Wang on Aug/15/2015

program main

   implicit none

   integer, parameter:: num=280,nc=281,dt=90,nstep=15,nij=180
   CHARACTER*256 :: WORKDIR
   CHARACTER suff*6
   integer:: i,nst,jk,ii,jj,ih
   real(8):: s(100),sg(101),va(nij),vpa_O(nij,100),vpa_H(nij,100)
   real(8):: vpa_He(nij,100),sumO(100),sumH(100),sumHe(100)
   real(8):: Re,ds,cvol(100),GL0(100),GLL(101),GL1(100)
   real(8):: denO(100),denH(100),denHe(100),dene(100)
   real(8),dimension(nstep):: Neq_O,Neq_H,Neq_He,Neq_e

   data Re/6371.2/


! Get WORKDIR of current working directory
     CALL GETCWD(WORKDIR)

     OPEN(212,File='Neq_time2hrs.dat',status='unknown')

     do i=1,nstep   
        nst=(i-1)*dt
        write(suff,'(i6)') nst
        suff=adjustl(suff)

        ds=0.0d0; s=0.0d0; sg=0.0d0
        sumO=0.0; sumH=0.0; sumHe=0.0     

        OPEN(208,FILE=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/cvol_vdistr'//trim(suff)//'.dat', &
             status='old')

        do jk=1,100
           read(208,*) ih,cvol(jk),GL0(jk)
        enddo
        CLOSE(208)     

        ! magnetic latitude in degree at the boundary of each cell
        GLL(1:51)=GL0(1:51)
        do jk=52,101
           GLL(jk)=-1.0*GL0(102-jk)
        enddo

        do jk=1,100
           GL1(jk)=(GLL(jk)+GLL(jk+1))/2.0
        enddo
                    
 !**********************  Oxygen  ****************************
        OPEN(207,FILE=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/OVPA'//trim(suff)//'.dat', &
               status='old')     
        do jk=1,100
            ! in km located in the center of the grid cell
           read(207,*) s(jk)
        enddo

       do jk=1,nij
           read(207,*) va(jk)
       enddo

       do ii=1,100
         do jj=1,nij
              read(207,*) vpa_O(jj,ii)
         enddo
      enddo
        
      CLOSE(207)

      ds=(s(2)-s(1))/2.0
      ! arc length located at the boundary of each cell
      sg(1)=s(1)-ds
      do jk=2,101
           sg(jk)=s(jk-1)+ds
      enddo
      sg(1:101)=sg(1:101)/Re    ! unit in Re
      
 !**********************  Hydrog  ****************************
      OPEN(209,FILE=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/HVPA'//trim(suff)//'.dat', &
               status='old')     
      do jk=1,100
            ! in km located in the center of the grid cell
         read(209,*) s(jk)
      enddo

      do jk=1,nij
          read(209,*) va(jk)
      enddo

      do ii=1,100
         do jj=1,nij
             read(209,*) vpa_H(jj,ii)
         enddo
      enddo
        
      CLOSE(209)

 !**********************  Helium  ****************************
      OPEN(210,FILE=WORKDIR(:LNBLNK(WORKDIR))//'/PLOT/HeVPA'//trim(suff)//'.dat', &
               status='old')     
      do jk=1,100
            ! in km located in the center of the grid cell
         read(210,*) s(jk)
      enddo

      do jk=1,nij
          read(210,*) va(jk)
      enddo

      do ii=1,100
         do jj=1,nij
             read(210,*) vpa_He(jj,ii)
         enddo
      enddo
        
      CLOSE(210)      

      do ii=1,100
         do jj=1,nij
            sumO(ii)=sumO(ii)+vpa_O(jj,ii)
            sumH(ii)=sumH(ii)+vpa_H(jj,ii)
            sumHe(ii)=sumHe(ii)+vpa_He(jj,ii)
         enddo
      enddo

      denO(1:100)=sumO(1:100)*1e-6/cvol(1:100)
      denH(1:100)=sumH(1:100)*1e-6/cvol(1:100)
      denHe(1:100)=sumHe(1:100)*1e-6/cvol(1:100)

      call smooth(denO,100)
      call smooth(denO,100)
      call smooth(denH,100)
      call smooth(denHe,100)
          


      ! unit in cm-3
      dene(1:100)=denO(1:100)+denH(1:100)+denHe(1:100)

      OPEN(211,FILE='den_distr'//trim(suff)//'.dat', &
               status='unknown')  
      do ii=1,100
         write(211,*) ii,s(ii),GL1(ii),denO(ii),denH(ii),&
               denHe(ii),dene(ii)
      enddo
      CLOSE(211)

      Neq_O(i)=(denO(50)+denO(51))/2.0
      Neq_H(i)=(denH(50)+denH(51))/2.0
      Neq_He(i)=(denHe(50)+denHe(51))/2.0      

  enddo

  call smooth(Neq_O,nstep)
  call smooth(Neq_H,nstep)
  call smooth(Neq_He,nstep)

  Neq_e=Neq_O+Neq_H+Neq_He
  do i=1,nstep
     write(212,*) i,Neq_O(i),Neq_H(i),Neq_He(i),Neq_e(i)
  enddo

  close(212)

end program

!-----------------------------------------------------------------------
!   Weighted 5-point average 04/30/98	X.Y.WU
!-----------------------------------------------------------------------
 subroutine smooth(temp,n)
     implicit none
     integer n,i
     real(8) temp(n)
     real(8), allocatable :: tempt(:)

     allocate(tempt(n))

     tempt(1)=(3.0d0*temp(1)+2.0d0*temp(2)+temp(3))/6.0d0
     tempt(2)=(2.0d0*temp(1)+3.0d0*temp(2)+2.0d0*temp(3)+temp(4))/8.0d0
     do i=3,n-2
         tempt(i)=(temp(i-2)+2.0d0*temp(i-1)+3.0d0*temp(i)+2.*temp(i+1)+ &
                 temp(i+2))/9.0d0
     enddo
     tempt(n-1)=(2.0d0*temp(n)+3.0d0*temp(n-1)+2.*temp(n-2)+temp(n-3))/8.0d0
     tempt(n)=(3.0d0*temp(n)+2.*temp(n-1)+temp(n-2))/6.0d0

     do i=1,n
         temp(i)=tempt(i)
     enddo

     deallocate(tempt)

end subroutine smooth
      

      
      

