!     
! File:   MS_POSITION.f90
! Calculate the dayside magnetopause given by the
! MODEL MAGNETOPAUSE OF SHUE ET AL. (JGR-A, V.103, P. 17691, 1998).
! 
! Revised on Jan. 23 2015, Created on June 20, 2012 by Yan Wang
!

SUBROUTINE MS_POSITION(BZIMF,XN_PD)

    USE GRIDPARAM
    implicit none

    real Et(3),Vsx,Vsy,Vsz,Ecr(3),Ecv(3)

    real bfd,Re,Be
    real(8) dh,we0,curt0,Veq,Vcr,L_eqe,V
    real Vs(3)

    real COLAT,XLON,MAGLON
    real tmp1,tmp2,pi
    real XGEO,YGEO,ZGEO,XGSW,YGSW,ZGSW
    real XSM,YSM,ZSM,MLAT

    Integer i,j,k
    real XMAG_eqe,YMAG_eqe,ZMAG_eqe,MCOLAT,MLON
    real XN_PD,BZIMF,XMGNP,YMGNP,ZMGNP,DIST
    integer ID

    REAL SEC,R_eqe,s0,s,P_c,SEC_start
    Real BLATD,BLONG,GLATD,GLONG,BCOLAT,GCOLAT,alt,ALT1
    Real GLON,XFGEO,YFGEO,ZFGEO,XFMAG,YFMAG,ZFMAG
    Real ZB,XBMAG,YBMAG,ZBMAG,XBMAG0,YBMAG0,ZBMAG0
    Real ZBLATD,ZBCOLAT,dl1,dl2
    Real VGSEX1,VGSEY1,VGSEZ1

    Character(len=10) charac1
    Character(len=12) charac2
    real F107
    integer Dst
    real Kr,Krr,Rar,H,dH_dr,dH_dphi,dP_dr,dP_dphi

    integer step
    integer LNBLNK
    character suff*6
    real  starttime,endtime
    real(8) R_s0, ALPHA,THETA
    REAL XGSM_MS,YGSM_MS,ZGSM_MS,XMAG_MS,YMAG_MS,ZMAG_MS,R_MS,MCOLAT_MS

    data Re/6371.2e3/,Be/3.11d-5/,pi/3.1415926/,P_c/1.34217728/

      CALL CPU_TIME(starttime)

      open(unit=71,file='Eqepos_MS.dat',status='unknown')
 !     write(71,*) '#        L[Re]       MLON[degree]      MLAT[degree]       XGSM[Re]     YGSM[Re]        ZGSM[Re]         XSM[Re]          YSM[Re]           ZSM[Re]'

 !   DEFINE THE UNIVERSAL TIME AND PREPARE THE COORDINATE TRANSFORMATION PARAMETERS
 !   BY INVOKING THE SUBROUTINE RECALC_08

      IYEAR=2001
      IDAY=90
      IHOUR=14
      IMIN=0
      ISEC=0
      
      VGSEX=-400.0
      VGSEY=0.0
      VGSEZ=0.0

      CALL RECALC_08 (IYEAR,IDAY,IHOUR,IMIN,ISEC,VGSEX,VGSEY,VGSEZ)

!  Define IMF Bz (nT)  and solar wind dynamic pressure (nPa) to calculate the position of the magentopause

!  the radial distance of the subsolar point on the magnetopause (Shue's model)
      R_s0=(10.22+1.29*TANH(0.184*(BZIMF+8.14)))*XN_PD**(-0.15151515)
      ALPHA=(0.58-0.007*BZIMF)*(1.0+0.024*ALOG(XN_PD))
      ZGSM_MS=0.0      
      do i=1,501
           THETA=-pi/2.0+(i-1)*pi/500.0           
            ! Define a point on the magnetopause      
            XGSM_MS=R_s0*(2.0/(1.0+COS(THETA)))**ALPHA*COS(THETA)
            YGSM_MS=R_s0*(2.0/(1.0+COS(THETA)))**ALPHA*SIN(THETA)

            ! Find the equatorial piont on the same field line as XGSM_MS, YGSM_MS, ZGSM_MS

           CALL GEOGSW_08(XGEO,YGEO,ZGEO,XGSM_MS,YGSM_MS,ZGSM_MS,-1)
      
           CALL GEOMAG_08(XGEO,YGEO,ZGEO,XMAG_MS,YMAG_MS,ZMAG_MS,1)      

           CALL SPHCAR_08 (R_MS,MCOLAT_MS,MLON,XMAG_MS,YMAG_MS,ZMAG_MS,-1)      
        
           !    THE LINE WILL STARTE FROM A  FOOTPOINT (unit Re) in the magentic equtorial plane ON THE MAGNETOPAUSE
           R_eqe=R_MS/((SIN(MCOLAT_MS))**2)
           MCOLAT=90.0*0.01745329

           !     CONVERT SPHERICAL COORDS INTO CARTESIAN COORDS  :
           CALL SPHCAR_08 (R_eqe,MCOLAT,MLON,XMAG_eqe,YMAG_eqe,ZMAG_eqe,1)

          !     CONVERT GEOMAGNETIC  COORDS INTO Solar Magnetic COORDS  :
          CALL MAGSM_08(XMAG_eqe,YMAG_eqe,ZMAG_eqe,XSM,YSM,ZSM,1)   
   
         CALL GEOMAG_08(XGEO,YGEO,ZGEO,XMAG_eqe,YMAG_eqe,ZMAG_eqe,-1)
         CALL GEOGSW_08(XGEO,YGEO,ZGEO,XGSW,YGSW,ZGSW,1)
     
         MAGLON=MLON/0.01745329
         MLAT=90.0d0-MCOLAT/0.01745329

         write(71,*) i,R_eqe,MAGLON,MLAT,XGSW,YGSW,ZGSW,XSM,YSM,ZSM

     enddo

END subroutine
